excel2moodle User Guide — excel2moodle 0.5.0 documentation

# excel2moodle User Guide

> The User Reference (table of contents below) gives a structured overview over the supported question Types and the tags that need to be filled out int the spreadsheet to produce them. The How-To section on the other hand gives a step-by-step explanation from filling the spreadsheet, to importing it to moodle.

- How To - Schritt für Schritt Anleitung
  - Excel2moodle unter Windows installieren
  - Fragensammlung in der Tabellenkalkulation erstellen
  - Export einer Fragen-Auswahl aus Excel2moodle
  - Import einer Fragensammlung in Moodle
  - Creating an exam question selection
  - Using the extra modules from the `Tools` section
- User Reference
  - Structure of a question database
  - Settings tag definitions
  - Question ID convention
  - Supported Question Types
  - Question Tag Definitions
- Fragenbeispiele
  - Vergleich der Fragen in Moodle und Tabelle
  - Example for a ``MC`` Question
  - Example for a ``NF`` Question
  - Example for a ``NFM`` Question

# excel2moodle Module documentation

This Python program helps to create Moodle questions in less time.

The aim is to put alle the information for the questions into a spreadsheet file, and then parse it, to generate Moodle compliant XML-Files. Furthermore this program lets you create a single `.xml`-File with a selection of questions, that then can be imported to a Moodle-Test.

## Concept

The concept is, to store the different questions into categories of similar types and difficulties of questions, for each of which, a separated sheet in the Spreadsheet document should be created.

There Should be a sheet called “Kategorien”, where an overview over the different categories is stored. This sheet stores The names and descriptions, for all categories. The name have to be the same as the actual sheet names with the questions. Furthermore the points used for grading, are set in the “Kategorien” sheet

## Functionality

- Parse multiple Choice Questions, each into one XML file

- Parse Numeric Questions, each into one XML file

- create single XML File from a selection of questions

# API documentation

- excel2moodle package
  - Concept
  - Functionality
  - Subpackages
- excel2moodle.extra package
  - Submodules
  - excel2moodle.extra.equationVerification module
- excel2moodle.core package
  - Submodules
  - excel2moodle.core.category module
  - excel2moodle.core.dataStructure module
  - excel2moodle.core.etHelpers module
  - excel2moodle.core.exceptions module
  - excel2moodle.core.globals module
  - excel2moodle.core.numericMultiQ module
  - excel2moodle.core.parser module
  - excel2moodle.core.question module
  - excel2moodle.core.validator module
  - excel2moodle.ui.settings module
  - excel2moodle.core.stringHelpers module
- excel2moodle.ui package
  - Submodules
  - excel2moodle.ui.appUi module
  - excel2moodle.ui.dialogs module
  - excel2moodle.ui.treewidget module
  - excel2moodle.ui.equationChecker module

## Indices and Tables

- Index

- Module Index

- Search Page